<?php

namespace Contactum\Fields;
use Contactum\Fields\Contactum_Field;
use Contactum\Fields\Traits\Textoption;

class Field_Text extends Contactum_Field {
    use Textoption;

	public function __construct() {
        $this->name       = __( 'Text', 'contactum' );
        $this->input_type = 'text_field';
        $this->icon       = 'text-width';
    }

    public function render( $field_settings, $form_id ) {
        $value = $field_settings['default']; ?>
        <li <?php $this->print_list_attributes( $field_settings ); ?>>
            <?php
                $this->print_label( $field_settings, $form_id );

                printf('<div class="contactum-fields"> <input type="text" name="%s" class="%s" id="%s" placeholder="%s" data-required="%s" data-type="text" value="%s" size="%s" /> </div>',
                    esc_attr( $field_settings['name'] ),
                    esc_attr( $field_settings['name'] ) . '_' . esc_attr( $form_id ),
                    esc_attr( $field_settings['name'] ) . '_' . esc_attr( $form_id ),
                    esc_attr( $field_settings['placeholder'] ),
                    esc_attr( $field_settings['required'] ),
                    esc_attr( $value ),
                    esc_attr( $field_settings['size'] )
                );

                $this->help_text( $field_settings );
            ?>
        </li>
    <?php }

    public function get_options_settings() {
        $default_options      = $this->get_default_option_settings();
        $default_text_options = $this->get_default_text_option_settings( false );
        $check_duplicate      = [
            [
                'name'          => 'duplicate',
                'title'         => 'No Duplicates',
                'type'          => 'checkbox',
                'is_single_opt' => true,
                'options'       => [
                    'no'   => __( 'Unique Values Only', 'contactum' ),
                ],
                'default'       => '',
                'section'       => 'advanced',
                'priority'      => 23,
                'help_text'     => __( 'Select this option to limit user input to unique values only. This will require that a value entered in a field does not currently exist in the entry database for that field.', '' ),
            ]
        ];
        return array_merge( $default_options, $default_text_options, $check_duplicate );
    }

    public function get_field_props() {
        $defaults = $this->default_attributes();
        $props = [
            // 'word_restriction' => '',
            'duplicate'        => '',
        ];

    	return array_merge( $defaults, $props );
    }
}